@@ -56,7 +56,6 @@ class CHPLPG(Generator):
             # Auto refill of lubricant
             next_state.lubricant_l = self.config.lubricant_max_l
 
-        next_state.p_kw *= self.config.gsign
         next_state.q_kvar = 0
 
         self.state = next_state
@@ -68,9 +67,9 @@ class CHPLPG(Generator):
         if setpoint is not None:
             return abs(setpoint)
 
-        hour = self.inputs._now.hour
+        hour = self.inputs.now_dt.hour
         default = self.config.default_schedule[hour]
-        setpoint = self.config.pn_max_kw * default / 100
+        setpoint = self.config.p_max_kw * default / 100
 
         return abs(setpoint)
 
@@ -94,7 +93,7 @@ class CHPLPG(Generator):
                 self.state.is_active
                 and self.state.active_s < self.config.active_min_s
             ):
-                next_state.p_kw = self.config.pn_min_kw
+                next_state.p_kw = self.config.p_min_kw
 
     def _check_performance_limit(self, next_state):
         """Check if minimal performance is reached.
@@ -105,8 +104,8 @@ class CHPLPG(Generator):
         """
         if next_state.p_kw != 0:
             next_state.p_kw = max(
-                min(next_state.p_kw, self.config.pn_max_kw),
-                self.config.pn_min_kw,
+                min(next_state.p_kw, self.config.p_max_kw),
+                self.config.p_min_kw,
             )
 
     def _check_lubricant(self, next_state):
@@ -169,25 +168,25 @@ class CHPLPG(Generator):
         super().set_state(state_dict)
         self._storage.t_c = self.state.storage_t_c
 
-    @property
-    def set_percent(self):
-        p_kw = self.inputs.p_set_kw
-        if p_kw is None:
-            p_kw = self.state.p_kw
+    # @property
+    # def set_percent(self):
+    #     p_kw = self.inputs.p_set_kw
+    #     if p_kw is None:
+    #         p_kw = self.state.p_kw
 
-        p_kw = (p_kw - self.config.pn_min_kw) / (
-            self.config.pn_max_kw - self.config.pn_min_kw
-        )
-        return abs(p_kw) * 100
+    #     p_kw = (p_kw - self.config.pn_min_kw) / (
+    #         self.config.pn_max_kw - self.config.pn_min_kw
+    #     )
+    #     return abs(p_kw) * 100
 
-    @set_percent.setter
-    def set_percent(self, value):
-        value = max(min(abs(value), 100.0), 0.0)
+    # @set_percent.setter
+    # def set_percent(self, value):
+    #     value = max(min(abs(value), 100.0), 0.0)
 
-        if value == 0:
-            p_set_kw = 0
-        else:
-            p_range = self.config.pn_max_kw - self.config.pn_min_kw
-            p_set_kw = self.config.pn_min_kw + value / 100 * p_range
+    #     if value == 0:
+    #         p_set_kw = 0
+    #     else:
+    #         p_range = self.config.pn_max_kw - self.config.pn_min_kw
+    #         p_set_kw = self.config.pn_min_kw + value / 100 * p_range
 
-        self.inputs.p_set_kw = p_set_kw
+    #     self.inputs.p_set_kw = p_set_kw
