@@ -79,9 +79,9 @@ class PhotovoltaicPowerPlant(Generator):
 
     """
 
-    def __init__(self, params, init_vals):
+    def __init__(self, params, inits):
         self.config = PVConfig(params)
-        self.state = PVState(init_vals)
+        self.state = PVState(inits)
         self.inputs = PVInputs()
 
     def step(self):
