@@ -11,11 +11,11 @@ from pysimmods.other.invertersim.inverter import Inverter
 class PVPlantSystem(QGenerator):
     """Pv system with pv modules and inverter"""
 
-    def __init__(self, params, init_vals):
+    def __init__(self, params, inits):
         self.config = PVSystemConfig(params)
         self.inputs = PVSystemInputs()
-        self.state = PVSystemState(init_vals)
-        self.pv = PhotovoltaicPowerPlant(params["pv"], init_vals["pv"])
+        self.state = PVSystemState(inits)
+        self.pv = PhotovoltaicPowerPlant(params["pv"], inits["pv"])
         self.inverter = Inverter(params["inverter"])
 
     def step(self):
