@@ -209,18 +209,19 @@ class FlexibilitySimulator(mosaik_api.Simulator):
                 else:
                     # Apply correction of the attr if necessary
                     if attr in ("p_mw", "p_th_mw", "q_mvar"):
-                        attr = attr.replace("m", "k")
+                        true_attr = attr.replace("m", "k")
+                    else:
+                        true_attr = attr
 
-                    if attr == "p_kw":
+                    if true_attr == "p_kw":
                         value = self.models[eid].get_p_kw()
-                    elif attr == "q_kvar":
+                    elif true_attr == "q_kvar":
                         value = self.models[eid].get_q_kvar()
                     else:
-                        value = getattr(self.models[eid].state, attr)
+                        value = getattr(self.models[eid].state, true_attr)
 
                     # Apply correction of the value if necessary
-                    if attr in ("p_kw", "p_th_kw", "q_kvar"):
-                        attr = attr.replace("k", "m")
+                    if attr in ("p_mw", "p_th_mw", "q_mvar"):
                         value *= 1e-3
 
                 data.setdefault(eid, dict())[attr] = value
