@@ -34,7 +34,13 @@ class InverterConfig(ModelConfig):
         super().__init__(params)
 
         self.s_max_kva = params["sn_kva"]
-        self._controls = ["p_set", "q_set", "cos_phi_set", "pq_set", "qp_set"]
+        self._controls = [
+            "p_set",
+            "q_set",
+            "cos_phi_set",
+            "pq_set",
+            "qp_set",
+        ]
         self.q_control = QControl[params.get("q_control", "p_set").upper()]
         self.cos_phi = params.get("cos_phi", 0.9)
         self.inverter_mode = params.get("inverter_mode", "capacitive")
